@@ -18,7 +18,6 @@ from cdp_backend.pipeline.ingestion_models import (
     Body,
     EventIngestionModel,
     EventMinutesItem,
-    IngestionModel,
     Matter,
     MinutesItem,
     Person,
@@ -27,9 +26,9 @@ from cdp_backend.pipeline.ingestion_models import (
     Vote,
     Role,
 )
-import pytz
 
 from .types import ContentURIs
+from .scraper_utils import IngestionModelScraper, reduced_list, str_simplified
 
 ###############################################################################
 
@@ -366,60 +365,7 @@ def get_legistar_events_for_timespan(
     return response
 
 
-def str_simplified(input_str: str) -> str:
-    """
-    Remove leading and trailing whitespaces, simplify multiple whitespaces, unify
-    newline characters.
-
-    Parameters
-    ----------
-    input_str: str
-
-    Returns
-    -------
-    cleaned: str
-        input_str stripped if it is a string
-    """
-    if not isinstance(input_str, str):
-        return input_str
-
-    input_str = input_str.strip()
-    # unify newline to \n
-    input_str = re.sub(r"[\r\n\f]+", r"\n", input_str)
-    # multiple spaces and tabs to 1 space
-    input_str = re.sub(r"[ \t\v]+", " ", input_str)
-
-    # Replace utf-8 char encodings with single utf-8 chars themselves
-    input_str = input_str.encode("utf-8").decode("utf-8")
-
-    return input_str
-
-
-def reduced_list(input_list: List[Any], collapse: bool = True) -> Optional[List]:
-    """
-    Remove all None items from input_list.
-
-    Parameters
-    ----------
-    input_list: List[Any]
-        Input list from which to filter out items that are None
-    collapse: bool, default = True
-        If True, return None in place of an empty list
-
-    Returns
-    -------
-    reduced_list: Optional[List]
-        All items in the original list except for None values.
-        None if all items were None and collapse is True.
-    """
-    filtered = [item for item in input_list if item is not None]
-    if collapse and len(filtered) == 0:
-        filtered = None
-
-    return filtered
-
-
-class LegistarScraper:
+class LegistarScraper(IngestionModelScraper):
     """
     Base class for transforming Legistar API data to CDP IngestionModel.
 
@@ -513,8 +459,9 @@ class LegistarScraper:
         minutes_item_decision_failed_pattern: str = r"not|fail",
         known_persons: Optional[Dict[str, Person]] = None,
     ):
+        super().__init__(timezone=timezone)
+
         self.client_name: str = client
-        self.timezone: pytz.timezone = pytz.timezone(timezone)
         self.ignore_minutes_item_patterns: List[str] = ignore_minutes_item_patterns
 
         # regex patterns used to infer cdp_backend.database.constants
@@ -539,115 +486,6 @@ class LegistarScraper:
 
         self.known_persons = known_persons
 
-    @staticmethod
-    def get_required_attrs(model: IngestionModel) -> List[str]:
-        """
-        Return list of keys required in model as specified in IngestionModel class
-        definition.
-
-        Parameters
-        ----------
-        model: IngestionModel
-            Person, MinutesItem, etc.
-
-        Returns
-        -------
-        attr_keys: List[str]
-            List of keys (attributes) in model without default value in class
-            definition.
-        """
-        try:
-            # create an empty one to have python tell us what keys are required
-            model.__class__()
-            # all attrs in model have default values
-            return []
-        except TypeError as e:
-            # e.g. __init__() missing 3 required positional arguments:
-            # 'session_datetime', 'video_uri', and 'session_index'
-            match = re.search(
-                r"missing (?P<num_keys>\d+) required.+argument(?:s)?\:\s*(?P<keys>.+)",
-                str(e),
-            )
-
-        if not match:
-            log.debug(f"not able to get required attributes for {model.__class__}")
-            return []
-
-        num_keys = int(match.group("num_keys"))
-
-        # 'session_datetime', 'video_uri', and 'session_index'
-        # -> ["session_datetime", "video_uri", "session_index"]
-
-        # SHOULD be able to do this more elegantly using re.split()
-        # but couldn't quite get the pattern right
-        keys = re.sub(
-            # TypeError uses
-            # , and
-            # and
-            # ,
-            # as delimiters for attribute names
-            r"(\s*,\s*and\s*)|(\s*and\s*)|(\s*,\s*)",
-            ",",
-            match.group("keys").strip().replace("'", ""),
-        ).split(",")
-
-        if num_keys != len(keys):
-            log.debug(f"{model.__class__} has {num_keys} required keys but got {keys}")
-
-        return keys
-
-    def get_none_if_empty(self, model: IngestionModel) -> Optional[IngestionModel]:
-        """
-        Check required keys in model, return None if any such key has no value.
-        i.e. If all required keys have valid value, return as-is.
-
-        Parameters
-        ----------
-        model: IngestionModel
-            Person, MinutesItem, etc.
-
-        Returns
-        -------
-        model: Optional[IngestionModel]
-            None or model as-is
-        """
-        try:
-            min_keys = self.min_ingestion_keys[model.__class__]
-        except AttributeError:
-            # first time using min_ingestion_keys
-            self.min_ingestion_keys = {}
-            min_keys = None
-        except KeyError:
-            # first time checking model.__class__
-            min_keys = None
-
-        if min_keys is None:
-            min_keys = LegistarScraper.get_required_attrs(model)
-            # cache so we don't do expensive dynamic checking
-            # again for this IngestionModel
-            self.min_ingestion_keys[model.__class__] = min_keys
-
-        if not min_keys:
-            # no required keys for this model
-            # this probably never happens
-            return model
-
-        for key in min_keys:
-            try:
-                val = getattr(model, key)
-
-                # "if not" test to catch all None and None-like values
-                # e.g. empty string, empty list, ...
-                # but int(0) is not "empty"
-                if not val and not isinstance(val, int):
-                    # empty value for this key in model
-                    return None
-            except AttributeError:
-                return None
-
-        # nonempty value for all required keys in model
-        return model
-
     def get_matter_status(self, legistar_matter_status: str) -> Optional[str]:
         """
         Return appropriate MatterStatusDecision constant from EventItemMatterStatus.
@@ -1203,53 +1041,6 @@ class LegistarScraper:
             ]
         )
 
-    @staticmethod
-    def find_time_zone() -> str:
-        """
-        Return name for a US time zone matching UTC offset calculated from OS clock.
-        """
-        utc_now = pytz.utc.localize(datetime.utcnow())
-        local_now = datetime.now()
-
-        for zone_name in pytz.country_timezones("us"):
-            zone = pytz.timezone(zone_name)
-            # if this is my time zone
-            # utc_now as local time should be VERY close to local_now
-            if (
-                abs(
-                    (
-                        utc_now.astimezone(zone) - zone.localize(local_now)
-                    ).total_seconds()
-                )
-                < 5
-            ):
-                return zone_name
-
-        return None
-
-    def localize_datetime(self, local_time: datetime) -> datetime:
-        """
-        Return input datetime with time zone information.
-        This allows for nonambiguous conversions to other zones including UTC.
-
-        Parameters
-        ----------
-        local_time: datetime
-            The datetime to attached timezone information to.
-
-        Returns
-        -------
-        local_time: datetime
-            The date and time attributes (year, month, day, hour, ...) remain unchanged.
-            tzinfo is now provided.
-        """
-        try:
-            return self.timezone.localize(local_time)
-        except (AttributeError, ValueError):
-            # AttributeError: time_zone or local_time is None
-            # ValueError: local_time is not navie (has time zone info)
-            return local_time
-
     @staticmethod
     def date_and_time_to_datetime(ev_date: str, ev_time: Optional[str]) -> datetime:
         """
@@ -1344,9 +1135,13 @@ class LegistarScraper:
             return person
 
         for attr in person.__dataclass_fields__.keys():
-            # input person has new information so prefer that
-            # over static long-term information
-            setattr(person, attr, getattr(person, attr) or getattr(known_person, attr))
+            static_info = getattr(known_person, attr)
+            if static_info is not None:
+                # have long-term information provided in "static*.json"; just use it
+                setattr(person, attr, static_info)
+            else:
+                # use dynamically obtained information, which may be None
+                setattr(person, attr, getattr(person, attr))
 
         # now that we have seat from static hard-coded data
         # we can bring in seat.roles (OfficeRecords from Legistar API)
